<?php
/*
Plugin Name: Ultimate Row Gradient Background Light for WPBakery Page Builder
Plugin URI: https://plugins.wp-preview.com/ultimate-row-gradient/
Description: Add static or animated gradient backgrounds for any row.
Author: dedalx
Version: 1.0
Author URI: https://magniumthemes.com/
Text Domain: urg
License: GPL
*/

/*
* Core plugin class
*/
if (!class_exists('URG_Core')) {
  class URG_Core {

    public function __construct() {

      // Constants
      define("URGL_PLUGIN_DIR", plugin_dir_url( '' ) . basename( dirname( __FILE__ ) ));
      define("URGL_PLUGIN_PATH", plugin_dir_path( __FILE__ ));
      define("URGL_PLUGIN_FILE", 'ultimate-row-gradient-light/ultimate-row-gradient-light.php');

      // Load init
      add_action('after_setup_theme', array($this, 'urg_init'));

      // Load elements
      if(defined('WPB_VC_VERSION')) {
        require URGL_PLUGIN_PATH . 'includes/shortcodes.php';
      } else {
        add_action('admin_notices', array($this, 'urg_admin_notice_vc_required'));
      }

      // Deactivation hook
      register_deactivation_hook( __FILE__, array($this, 'urg_deactivation'));

    }

    // Plugin deactivation
    public function urg_deactivation() {
      // Clear the permalinks to remove our post type's rules
      flush_rewrite_rules();
    }

    // Load textdomain
    public function urg_load_textdomain() {
      load_plugin_textdomain( 'urg', false, basename( dirname( __FILE__ ) ) . '/languages' );
    }

    // Init plugin
    public function urg_init() {

      // Load translated strings
      add_action('init', array($this, 'urg_load_textdomain'));

      // Add scripts and styles
      add_action('init', array($this, 'urg_scripts'));
      add_action('admin_init', array($this, 'urg_admin_scripts'));

      // Load dashboard
      require URGL_PLUGIN_PATH . 'includes/dashboard/dashboard.php';

      // Load helper class
      require URGL_PLUGIN_PATH . 'includes/helper.php';

    }

    // Add scripts and styles to frontend
    public function urg_scripts() {

        wp_enqueue_style('urg-styles-frontend', URGL_PLUGIN_DIR . '/assets/css.css');

    }

    // Add scripts and styles to backend
    public function urg_admin_scripts() {

    }

    // WPBakery Page Builder activation notice
    public function urg_admin_notice_vc_required() {

        $is_multisite = is_multisite();
        $is_network_admin = is_network_admin();
        if ( ( $is_multisite && $is_network_admin ) || ! $is_multisite ) {
        ?>
        <div class="notice notice-error">
            <p><?php esc_html_e('WPBakery Page Builder plugin must be installed and activated for Ultimate Magnium Addons plugin functionality.', 'urg'); ?></p>
        </div>
        <?php
        }
    }

  }
}

new URG_Core();
